# Vue File Uploader

一个支持 Vue 2.x 和 Vue 3.x 的文件上传组件，提供拖拽上传、进度显示、文件预览等功能。

## 特性

- 🎯 支持 Vue 2.x 和 Vue 3.x
- 📦 支持 ESM 和 CommonJS
- 🚀 支持拖拽上传
- 📊 实时上传进度
- 🎨 美观的 UI 界面
- 📝 完整的 TypeScript 类型支持
- 🛠 高度可定制

## 安装

```bash
npm install @saberlayer/vue-file-uploader
# 或
yarn add @saberlayer/vue-file-uploader
```

## 使用方法

### 全局注册

```typescript
// Vue 3.x
import { createApp } from 'vue'
import FileUploader from '@saberlayer/vue-file-uploader'

const app = createApp(App)
app.use(FileUploader)

// Vue 2.x
import Vue from 'vue'
import FileUploader from '@saberlayer/vue-file-uploader'

Vue.use(FileUploader)
```

### 局部注册

```typescript
import { FileUploader } from '@saberlayer/vue-file-uploader'

export default {
  components: {
    FileUploader
  }
}
```

### 基础用法

```vue
<template>
  <file-uploader
    action="/api/upload"
    v-model:fileList="fileList"
    @change="handleChange"
    @success="handleSuccess"
    @error="handleError"
  />
</template>

<script>
import { ref } from 'vue'

export default {
  setup() {
    const fileList = ref([])

    const handleChange = ({ file, fileList }) => {
      console.log('文件变化：', file, fileList)
    }

    const handleSuccess = (file, fileList) => {
      console.log('上传成功：', file)
    }

    const handleError = (error, file) => {
      console.log('上传失败：', error)
    }

    return {
      fileList,
      handleChange,
      handleSuccess,
      handleError
    }
  }
}
</script>
```

## API

### Props

| 参数 | 说明 | 类型 | 默认值 |
|------|------|------|--------|
| action | 上传的地址（必填） | string | - |
| multiple | 是否支持多文件上传 | boolean | false |
| accept | 接受的文件类型 | string | - |
| maxSize | 文件大小限制（字节） | number | 0 |
| maxCount | 最大文件数 | number | 0 |
| headers | 自定义请求头 | object | {} |
| data | 上传时附带的额外参数 | object | {} |
| autoUpload | 是否自动上传 | boolean | true |
| fileList | 文件列表 | UploadFile[] | [] |

### Events

| 事件名 | 说明 | 回调参数 |
|--------|------|----------|
| change | 文件状态改变时触发 | { file, fileList } |
| success | 上传成功时触发 | (file, fileList) |
| error | 上传失败时触发 | (error, file) |
| exceed | 超出文件数限制时触发 | files |

### Slots

| 插槽名 | 说明 | 参数 |
|--------|------|------|
| default | 自定义上传区域的内容 | - |

### 类型定义

```typescript
interface UploadFile {
  uid: string;
  name: string;
  size: number;
  type: string;
  status: 'ready' | 'uploading' | 'success' | 'error';
  percentage?: number;
  response?: any;
  url?: string;
  error?: any;
}
```

## 示例

### 自定义上传区域

```vue
<template>
  <file-uploader action="/api/upload">
    <div class="custom-upload">
      <button>选择文件</button>
      <p>或将文件拖拽到此处</p>
    </div>
  </file-uploader>
</template>
```

### 文件大小和数量限制

```vue
<template>
  <file-uploader
    action="/api/upload"
    :maxSize="5 * 1024 * 1024"
    :maxCount="3"
    @exceed="handleExceed"
  />
</template>

<script>
export default {
  setup() {
    const handleExceed = (files) => {
      alert('超出文件数量限制')
    }

    return { handleExceed }
  }
}
</script>
```

### 手动上传

```vue
<template>
  <file-uploader
    ref="uploader"
    action="/api/upload"
    :autoUpload="false"
  />
  <button @click="submitUpload">开始上传</button>
</template>

<script>
import { ref } from 'vue'

export default {
  setup() {
    const uploader = ref(null)

    const submitUpload = () => {
      uploader.value?.submit()
    }

    return {
      uploader,
      submitUpload
    }
  }
}
</script>
```

## 浏览器支持

- 支持所有现代浏览器
- IE 11+（需要相应的 polyfill）

## 许可证

MIT 